<?php

namespace Drupal\cmlmigrations\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Implements the form controller.
 */
class SettingsMigrations extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'cmlmigrations_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['cmlmigrations.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('cmlmigrations.settings');
    $form['mapping'] = [
      '#type' => 'details',
      '#title' => $this->t('Mapping'),
      '#open' => TRUE,
    ];
    $form['pipeline']['timeout'] = [
      '#title' => $this->t('Timeout'),
      '#type' => 'textfield',
      '#default_value' => $config->get('timeout'),
      '#description' => $this->t('Max migration time before failure (minute)'),
    ];
    $vocabulares = [];
    if (\Drupal::moduleHandler()->moduleExists('taxonomy')) {
      $vocabulares = taxonomy_vocabulary_get_names();
    }
    $form['mapping']['vocabulary'] = [
      '#title' => $this->t('Catalog Vocabulary'),
      '#type' => 'select',
      '#options' => $vocabulares,
      '#default_value' => $config->get('vocabulary'),
    ];
    $form['pipeline'] = [
      '#type' => 'details',
      '#title' => $this->t('Pipeline'),
    ];
    $form['pipeline']['timeout'] = [
      '#title' => $this->t('Timeout'),
      '#type' => 'textfield',
      '#default_value' => $config->get('timeout'),
      '#description' => $this->t('Max migration time before failure (minute)'),
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * Implements form validation.
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {

  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('cmlmigrations.settings');
    $timeout = trim($form_state->getValue('timeout'));
    if (!is_numeric($timeout)) {
      $timeout = 60;
    }
    $config
      ->set('vocabulary', $form_state->getValue('vocabulary'))
      ->set('timeout', $timeout)
      ->save();
  }

}
